@@ -19,11 +19,18 @@
 #include <QFile>
 #include <QJsonArray>
 #include <QJsonDocument>
-#include <QJsonObject>
 #include <QObject>
 #include <QProcess>
 #include <QTest>
 
+void initLocale()
+{
+    // use some exotic locale to ensure the date/time parsing doesn't just work by luck
+    qputenv("LANG", "fr_FR");
+}
+
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+
 using namespace KItinerary;
 
 /** Note: this test requires external test data that is not publicly available,
@@ -40,9 +47,6 @@ private:
 private Q_SLOTS:
     void initTestCase()
     {
-        // use some exotic locale to ensure the date/time parsing doesn't just work by luck
-        QLocale::setDefault(QLocale(QStringLiteral("fr_FR")));
-
         //m_engine.setUseSeparateProcess(true);
     }
 
@@ -56,7 +60,7 @@ private Q_SLOTS:
                 continue;
             }
 
-            QDirIterator it(baseDir.path(), {QStringLiteral("*.txt"), QStringLiteral("*.html"), QStringLiteral("*.pdf"), QStringLiteral("*.pkpass"), QStringLiteral("*.ics"), QStringLiteral("*.eml"), QStringLiteral("*.mbox")}, QDir::Files | QDir::Readable | QDir::NoSymLinks, QDirIterator::Subdirectories);
+            QDirIterator it(baseDir.path(), {QStringLiteral("*.txt"), QStringLiteral("*.html"), QStringLiteral("*.pdf"), QStringLiteral("*.pkpass"), QStringLiteral("*.ics"), QStringLiteral("*.eml"), QStringLiteral("*.mbox"), QStringLiteral("*.bin")}, QDir::Files | QDir::Readable | QDir::NoSymLinks, QDirIterator::Subdirectories);
             while (it.hasNext()) {
                 it.next();
                 // ignore context files
