@@ -36,7 +36,7 @@ enum {
 };
 
 
-static constexpr const auto SQUARE_MAX_ASPECT = 1.2f;
+static constexpr const auto SQUARE_MAX_ASPECT = 1.25f;
 static constexpr const auto PDF417_MIN_ASPECT = 1.5f;
 static constexpr const auto PDF417_MAX_ASPECT = 6.0f;
 static constexpr const auto ANY1D_MIN_ASPECT = 6.0f;
@@ -249,7 +249,7 @@ void BarcodeDecoder::decodeZxing(const QImage &img, BarcodeDecoder::BarcodeTypes
         if (std::any_of(res.text().begin(), res.text().end(), [](const auto c) { return c > 255; })) {
             result.contentType &= ~Result::ByteArray;
         }
-        if (std::any_of(res.text().begin(), res.text().end(), [](const auto c) { return c < 20; })) {
+        if (std::any_of(res.text().begin(), res.text().end(), [](const auto c) { return c < 0x20; })) {
             result.contentType &= ~Result::String;
         }
 
